@@ -21,8 +21,15 @@ class SessionDTO(pydantic.BaseModel):
         """Return a boolean if the session has the specified Authentication
         Method Reference(s) (AMR).
         """
-        if max_age is not None:
-            raise NotImplementedError
         if isinstance(amr, str):
             amr = {amr}
-        return bool(set(self.claims.amr) & amr)
\ No newline at end of file
+        has_required_methods = bool(amr <= set(self.claims.amr))
+        if not has_required_methods:
+            return False
+        if max_age:
+            for type in amr:
+                ref = self.claims.amr[type]
+                if not ref.is_effective(max_age):
+                    has_required_methods = False
+                    break
+        return has_required_methods
\ No newline at end of file
