@@ -15,7 +15,4 @@ class Subject(pydantic.BaseModel):
     challenge_id: int
     created: int = pydantic.Field(default_factory=timezone.now)
     primary_email: pydantic.EmailStr
-
-    #: The Level of Assurance (LoA) with regards to the asserted identity.
-    #:
-    ial: int = 1
+    allow_mfa: bool = False
\ No newline at end of file
