@@ -8,9 +8,11 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 from .subject import *
 from .token import DatastoreTokenRepository
+from .documentservice import DocumentServiceRepository
 
 
 __all__: list[str] = [
     'DatastoreSubjectRepository',
     'DatastoreTokenRepository',
+    'DocumentServiceRepository',
 ]
\ No newline at end of file
