@@ -7,8 +7,10 @@
 # distributed under the License is distributed on an "AS IS" BASIS,
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 from .email import EmailService
+from .fingerprint import FingerprintService
 
 
 __all__: list[str] = [
-    'EmailService'
+    'EmailService',
+    'FingerprintService',
 ]
\ No newline at end of file
