@@ -9,9 +9,11 @@
 from .apiresource import APIResource
 from .localsubjectrepository import LocalSubjectRepository
 from .principal import AuthenticatedSessionPrincipal
+from .servicerepository import ServiceRepository
 from .serviceresource import ServiceResource
 from .sessionendpoint import SessionEndpoint
 from .sessionresource import SessionResource
+from .storageencrypter import StorageEncrypter
 from .subjectresource import SubjectResource
 
 
@@ -22,5 +24,6 @@ __all__: list[str] = [
     'ServiceResource',
     'SessionEndpoint',
     'SessionResource',
+    'StorageEncrypter',
     'SubjectResource',
 ]
\ No newline at end of file
