@@ -10,6 +10,7 @@ import asyncio
 import functools
 from typing import Any
 from typing import Callable
+from typing import TypeVar
 
 import ddd
 from cbra.conf import settings
@@ -21,6 +22,9 @@ from google.cloud.datastore import Key
 from google.cloud.datastore import Query
 
 
+T = TypeVar("T")
+M = TypeVar("M")
+
 class GoogleDatastoreRepository(ddd.Repository):
     __module__: str = 'login.infra.repo'
     client: Client
@@ -45,6 +49,16 @@ class GoogleDatastoreRepository(ddd.Repository):
         super().__init__()
         self.client = client
 
+    async def allocate(self, base: Key) -> int:
+        key, *_ = await self.run_in_executor(
+            functools.partial( # type: ignore
+                self.client.allocate_ids, # type: ignore
+                incomplete_key=base,
+                num_ids=1
+            )
+        )
+        return key.id
+
     async def delete_key(self, key: Key) -> None:
         await self.run_in_executor(self.client.delete, key) # type: ignore
 
@@ -125,7 +139,7 @@ class GoogleDatastoreRepository(ddd.Repository):
             break
         return result
 
-    async def persist_model(self, obj: BaseModel) -> BaseModel:
+    async def persist_model(self, obj: T) -> T:
         entity = self.entity_factory(id=getattr(obj, self.id_attr))
         entity.update(obj.dict(exclude=self.exclude | {self.id_attr})) # type: ignore
         await self.put(entity)
