@@ -6,19 +6,21 @@
 # Unless required by applicable law or agreed to in writing, software
 # distributed under the License is distributed on an "AS IS" BASIS,
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+from typing import Any
+
 from cbra import Endpoint
-from cbra.conf import settings
-from cbra.cors import DefaultPolicy
+from cbra.types import ICorsPolicy
+
+from .cors import CORSPolicy
+from .principal import ISessionPrincipal
+from .principal import SessionPrincipal
 
-from .cookieidentifieddistributedsession import CookieIdentifiedDistributedSession
 
 
 class SessionEndpoint(Endpoint):
     __module__: str = 'libwebid.lib'
-    cors_policy: type[DefaultPolicy] = DefaultPolicy.new(
-        allow_credentials=True,
-        allowed_origins=settings.CORS_ALLOWED_HOSTS,
-        allowed_headers={"Content-Type", "Cookies"},
-        allowed_response_headers={"Set-Cookie"}
-    )
-    session: CookieIdentifiedDistributedSession
\ No newline at end of file
+    cors_policy: type[ICorsPolicy] = CORSPolicy
+    principal: ISessionPrincipal
+    principal_factory: Any = SessionPrincipal.fromcookie
+    require_authentication: bool = True
+    session_required: bool = False
\ No newline at end of file
